@@ -6,6 +6,7 @@ import re
 import struct
 import tempfile
 
+import dicomifier
 import nibabel
 import numpy
 import spire
@@ -67,7 +68,7 @@ class BrukerToMIF(spire.TaskFactory):
             meta_data = json.load(fd)
         
         bruker_data = json.loads(
-            base64.b64decode(meta_data["EncapsulatedDocument"][0]))
+            base64.b64decode(meta_data["EncapsulatedDocument"][0]).strip(b" \0"))
         
         # acqp = dicomifier.bruker.Dataset()
         # with tempfile.NamedTemporaryFile("w") as fd:
@@ -82,10 +83,9 @@ class BrukerToMIF(spire.TaskFactory):
         with tempfile.NamedTemporaryFile("w") as fd:
             fd.write(bruker_data["method"])
             method.load(fd.name)
-        # NOTE: is this still valid for multi-shot data?
-        # cf. PVM_EpiNShots
+        
         total_readout_time = 1e-3*(
-            (method["PVM_EpiNEchoes"].value[0]-1) 
+            (method["PVM_EpiNEchoes"].value[0]) 
             * method["PVM_EpiEchoSpacing"].value[0])
         
         phase_gradient = numpy.around(
